==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
var CheckedChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CheckedChangedEventArgsDescriptionMetadata, _super);
    function CheckedChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckedChangedEventArgsDescriptionMetadata.b = function (a) {
        if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
            CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(CheckedChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("IsChecked", "Boolean");
    };
    CheckedChangedEventArgsDescriptionMetadata.d = function (a) {
        CheckedChangedEventArgsDescriptionMetadata.b(a);
        a.u("CheckedChangedEventArgs", function () { return new CheckedChangedEventArgsDescription(); });
        a.t("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.$t = markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
}(Base));
export { CheckedChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
var CheckedChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CheckedChangedEventArgsDescriptionMetadata, _super);
    function CheckedChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckedChangedEventArgsDescriptionMetadata.b = function (a) {
        if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
            CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(CheckedChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("IsChecked", "Boolean");
    };
    CheckedChangedEventArgsDescriptionMetadata.d = function (a) {
        CheckedChangedEventArgsDescriptionMetadata.b(a);
        a.aa("CheckedChangedEventArgs", function () { return new CheckedChangedEventArgsDescription(); });
        a.z("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.$t = markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
}(Base));
export { CheckedChangedEventArgsDescriptionMetadata };
